ScorePack
=========

.. currentmodule:: pykeen.predict

.. autoclass:: ScorePack
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ScorePack.process

   .. rubric:: Methods Documentation

   .. automethod:: process
